##  Enabling SAP Suggestions
You can view SAP suggestions in landscape reports with applications. To enable SAP suggestions in a landscape report, activate the Enable SAP suggestions option in the report settings.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio252c31ecf50649ffb56cf93aa0b0e499_LowRes.png)
Enabling SAP Suggestions in a Report
